@@ -1,7 +1,7 @@
 //! Utilities for serializing Duper values.
 
 use crate::{
-    DuperTemporal,
+    DuperFloat, DuperTemporal,
     ast::{DuperIdentifier, DuperObject, DuperValue},
     format::{
         format_boolean, format_duper_bytes, format_duper_string, format_float, format_integer,
@@ -225,7 +225,11 @@ impl DuperVisitor for Serializer {
         }
     }
 
-    fn visit_float(&mut self, identifier: Option<&DuperIdentifier<'_>>, float: f64) -> Self::Value {
+    fn visit_float(
+        &mut self,
+        identifier: Option<&DuperIdentifier<'_>>,
+        float: DuperFloat,
+    ) -> Self::Value {
         if !self.strip_identifiers
             && let Some(identifier) = identifier
         {
@@ -270,7 +274,7 @@ mod serializer_tests {
     use insta::assert_snapshot;
 
     use super::Serializer;
-    use crate::{DuperIdentifier, DuperKey, DuperObject, DuperParser, DuperValue};
+    use crate::{DuperFloat, DuperIdentifier, DuperKey, DuperObject, DuperParser, DuperValue};
 
     fn example_value() -> DuperValue<'static> {
         DuperValue::Object {
@@ -311,15 +315,15 @@ mod serializer_tests {
                         inner: vec![
                             DuperValue::Float {
                                 identifier: None,
-                                inner: 18.5,
+                                inner: DuperFloat::assert(18.5),
                             },
                             DuperValue::Float {
                                 identifier: None,
-                                inner: 15.2,
+                                inner: DuperFloat::assert(15.2),
                             },
                             DuperValue::Float {
                                 identifier: None,
-                                inner: 7.8,
+                                inner: DuperFloat::assert(7.8),
                             },
                         ],
                     },
@@ -328,7 +332,7 @@ mod serializer_tests {
                     DuperKey(Cow::Borrowed("weight")),
                     DuperValue::Float {
                         identifier: Some(DuperIdentifier(Cow::Borrowed("Weight"))),
-                        inner: 0.285,
+                        inner: DuperFloat::assert(0.285),
                     },
                 ),
                 (
@@ -433,7 +437,7 @@ mod serializer_tests {
                                 DuperKey(Cow::Borrowed("average")),
                                 DuperValue::Float {
                                     identifier: None,
-                                    inner: 4.5,
+                                    inner: DuperFloat::assert(4.5),
                                 },
                             ),
                             (
